@@ -1,5 +1,4 @@
 package CHI::Test::Class;
-use CHI::Util qw(require_dynamic);
 use Getopt::Long;
 use Module::Load::Conditional qw(can_load);
 use strict;
@@ -55,9 +54,4 @@ sub required_modules {
     return {};
 }
 
-# magic borrowed from Test::Class::Load
-INIT {
-    CHI::Test->test_class->runtests;
-}
-
 1;
