@@ -14,6 +14,17 @@ sub new_cache_options {
     return ( $self->SUPER::new_cache_options(), global => 1 );
 }
 
+# If new_cache called with datastore, ignore global flag (otherwise would be an error)
+#
+sub new_cache {
+    my $self   = shift;
+    my %params = @_;
+    if ( $params{datastore} ) {
+        $params{global} = 0;
+    }
+    return CHI->new( $self->new_cache_options(), %params );
+}
+
 sub test_short_driver_name : Tests(1) {
     my ($self) = @_;
 
@@ -33,6 +44,8 @@ sub test_global_or_datastore_required : Tests(3) {
     is( $cache2->get('foo'), 5, "defaulted to global datastore" );
 }
 
+# Make sure two caches don't share datastore
+#
 sub test_different_datastores : Tests(1) {
     my $self   = shift;
     my $cache1 = CHI->new( driver => 'Memory', datastore => {} );
@@ -41,4 +54,15 @@ sub test_different_datastores : Tests(1) {
     ok( $cache2->is_empty() );
 }
 
+sub test_lru_discard : Tests(2) {
+    my $self = shift;
+    my $cache = $self->new_cleared_cache( max_size => 41 );
+    is( $cache->discard_policy, 'lru' );
+    my $value_20 = 'x' x 6;
+    foreach my $key ( map { "key$_" } qw(1 2 3 4 5 6 5 6 5 3 2) ) {
+        $cache->set( $key, $value_20 );
+    }
+    cmp_set( [ $cache->get_keys ], [ "key2", "key3" ] );
+}
+
 1;
